@@ -17,7 +17,7 @@ Binding Zope3 Schema Properties to Alchemist Mapped Classes
 $Id: property.py 299 2008-05-23 20:31:48Z kapilt $
 """
 
-from sqlalchemy.orm import attributes, class_mapper
+from sqlalchemy.orm import attributes
 from interfaces import IIModelInterface
 from zope import schema, interface
 
@@ -52,40 +52,32 @@ class ValidatedProperty( object ):
             raise ValueError(self.__name, 'field is readonly')
         self.__prop.__delete__( obj )
     
-def bindClass( klass ):
+def bindClass( klass, mapper=None ):
     """
     attach validation to a sqlalchemy mapped class, based on its implemented schemas, via property
     validators, taking care to wrap sqlalchemy properties.
     """
 
-    mapper = class_mapper( klass )
+    if mapper is None:
+        mapper = getattr( klass, 'mapper')
+
+    # compile the klass mapper, this will add instrumented attributes to the class
+    # we could alternatively do.. mapper.compile() compiles all extant mappers
 
-    # compile the klass mapper, this will add instrumented attributes to the class, 
-    # mapper.compile() compiles all extant mappers
     mapper.compile()
 
     # find all the model schemas implemented by the class
     for iface in interface.implementedBy( klass ):
         if not IIModelInterface.providedBy( iface ):
             continue
-        _bind( klass, iface )
-        
-def bind( klass ):
-    import sa2zs
-    iface = sa2zs.transmute( klass.mapper.tables[0] )
-    _bind( klass, iface )
 
-def _bind( klass, iface):
-    # for any field in the schema, see if we have an sa property
-    for field_name in schema.getFieldNames( iface ):
-        v = klass.__dict__.get( field_name )
-        
-        # if so then wrap it in a field property
-        if not isinstance( v, attributes.InstrumentedAttribute):
-            continue
-        
-        field = iface[ field_name ]
-        vproperty = ValidatedProperty( field, v, field_name )
-        setattr( klass, field_name, vproperty )
+        # for any field in the schema, see if we have an sa property
+        for field_name in schema.getFieldNames( iface ):
+            v = klass.__dict__.get( field_name )
 
-    
+            # if so then wrap it in a field property
+            if not isinstance( v, attributes.InstrumentedAttribute):
+                continue
+            field = iface[ field_name ]
+            vproperty = ValidatedProperty( field, v, field_name )
+            setattr( klass, field_name, vproperty )
